InodeWrapper

Enum InodeWrapper 

pub enum InodeWrapper {
    V5(RafsV5Inode),
    V6(RafsV6Inode),
    Ref(Arc<dyn RafsInodeExt>),
}
An inode object wrapper for different RAFS versions.

Variants



V5(RafsV5Inode)

Inode info structure for RAFS v5.



V6(RafsV6Inode)

Inode info structure for RAFS v6, reuse RafsV5Inode as IR for v6.



Ref(Arc<dyn RafsInodeExt>)

A reference to a RafsInodeExt object.

Implementations

Source

impl InodeWrapper

pub fn new(version: RafsVersion) -> Self

Create a new instance of InodeWrapper with default value.

pub fn from_inode_info(inode: Arc<dyn RafsInodeExt>) -> Self

Create an InodeWrapper object from a RafsInodeExt trait object.

pub fn is_v5(&self) -> bool

Check whether is a RAFS V5 inode.

pub fn is_v6(&self) -> bool

Check whether is a RAFS V6 inode.

pub fn inode_size(&self) -> usize

Get file content size of the inode.

pub fn mode(&self) -> u32

Get access permission/mode for the inode.

pub fn set_mode(&mut self, mode: u32)

Set access permission/mode for the inode.

pub fn is_dir(&self) -> bool

Check whether the inode is a directory.

pub fn is_reg(&self) -> bool

Check whether the inode is a regular file.

Check whether the inode is a hardlink.

Check whether the inode is a symlink.

pub fn is_chrdev(&self) -> bool

Check whether the inode is a char device node.

pub fn is_blkdev(&self) -> bool

Check whether the inode is a block device node.

pub fn is_fifo(&self) -> bool

Check whether the inode is a FIFO.

pub fn is_sock(&self) -> bool

Check whether the inode is a socket.

pub fn is_special(&self) -> bool

Check whether the inode is a special file, such chardev, blkdev, FIFO and socket.

Get inode flags.

Set whether the inode has HARDLINK flag set.

pub fn has_xattr(&self) -> bool

Check whether the inode has associated xattrs.

pub fn set_has_xattr(&mut self, enable: bool)

Set whether the inode has associated xattrs.

pub fn ino(&self) -> Inode

Get inode number.

pub fn set_ino(&mut self, ino: Inode)

Set inode number.

pub fn parent(&self) -> Inode

Get parent inode number, only for RAFS v5.

pub fn set_parent(&mut self, parent: Inode)

Set parent inode number, only for RAFS v5.

pub fn size(&self) -> u64

Get inode content size of regular file, directory and symlink.

pub fn set_size(&mut self, size: u64)

Set inode content size.

pub fn uid(&self) -> u32

Get user id associated with the inode.

pub fn set_uid(&mut self, uid: u32)

Set user id associated with the inode.

pub fn gid(&self) -> u32

Get group id associated with the inode.

pub fn set_gid(&mut self, gid: u32)

Set group id associated with the inode.

pub fn mtime(&self) -> u64

Get modified time.

pub fn set_mtime(&mut self, mtime: u64)

Set modified time.

pub fn mtime_nsec(&self) -> u32

Get nsec part of modified time.

pub fn set_mtime_nsec(&mut self, mtime_nsec: u32)

Set nsec part of modified time.

pub fn blocks(&self) -> u64

Get data blocks of file content, in unit of 512 bytes.

pub fn set_blocks(&mut self, blocks: u64)

Set data blocks of file content, in unit of 512 bytes.

pub fn rdev(&self) -> u32

Get real device id associated with the inode.

pub fn set_rdev(&mut self, rdev: u32)

Set real device id associated with the inode.

pub fn set_projid(&mut self, projid: u32)

Set project ID associated with the inode.

Get number of hardlinks.

Set number of hardlinks.

pub fn digest(&self) -> &RafsDigest

Get digest of inode metadata, RAFS v5 only.

pub fn set_digest(&mut self, digest: RafsDigest)

Set digest of inode metadata, RAFS v5 only.

pub fn name_size(&self) -> u16

Get size of inode name.

pub fn set_name_size(&mut self, size: usize)

Set size of inode name.

Get size of symlink.

Set size of symlink.

pub fn child_index(&self) -> u32

Get child inode index, only valid for RAFS v5.

pub fn set_child_index(&mut self, index: u32)

Set child inode index, only fro RAFS v5.

pub fn child_count(&self) -> u32

Get child/chunk count.

pub fn set_child_count(&mut self, count: u32)

Set child/chunk count.

pub fn create_chunk(&self) -> ChunkWrapper

Create a ChunkWrapper object to be associated with the inode.

pub fn get_inode_size_with_xattr( &self, xattrs: &RafsXAttrs, v6_compact: bool, ) -> usize

Get memory/disk space occupied by the inode structure, including xattrs.